@@ -4,7 +4,7 @@
 use DBI;
 use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our %results;
 
@@ -44,14 +44,22 @@ sub query {
     return $results{$self}{$result} = $result = DBIx::Simple::Result->new("$self", $sth);
 }
 
+sub commit {
+    my ($self) = @_;
+    $self->{dbi}->commit();
+}
+
+sub rollback {
+    my ($self) = @_;
+    $self->{dbi}->rollback();
+}
+
 sub DESTROY {
     my ($self) = @_;
     $results{$self}{$_}->DESTROY() for keys %{ $results{$self} };
     $self->disconnect();
 }
 
-'And nothing else matters';
-
 #------------------------------#
   package DBIx::Simple::Dummy;
 #------------------------------#
@@ -88,6 +96,11 @@ sub hash {
     return $self->{sth}->fetchrow_hashref;
 }
 
+sub flat {
+    my ($self) = @_;
+    return map @$_, $self->arrays;
+}
+
 sub arrays {
     my ($self) = @_;
     return @{ $self->{sth}->fetchall_arrayref };
@@ -101,6 +114,38 @@ sub hashes {
     return @return;
 }
 
+sub map_hashes {
+    my ($self, $keyname) = @_;
+    croak 'Key column name not optional' if not defined $keyname;
+    my @rows = $self->hashes;
+    my @keys;
+    for (@rows) {
+	push @keys, $_->{$keyname};
+	delete $_->{$keyname};
+    }
+    my %return;
+    @return{@keys} = @rows;
+    return \%return;
+}
+
+sub map_arrays {
+    my ($self, $keyindex) = @_;
+    $keyindex += 0;
+    my @rows = $self->arrays;
+    my @keys;
+    for (@rows) {
+	push @keys, splice @$_, $keyindex, 1;
+    }
+    my %return;
+    @return{@keys} = @rows;
+    return \%return;
+}
+
+sub map {
+    my ($self) = @_;
+    return { map { $_->[0] => $_->[1] } $self->arrays };    
+}
+
 sub rows {
     my ($self) = @_;
     return $self->{sth}->rows;
@@ -130,15 +175,13 @@ DBIx::Simple - An easy-to-use, object oriented interface to DBI
     my $db = DBIx::Simple->connect(
 	'DBI:mysql:database=test',     # DBI source specification
 	'test', 'test',                # Username and password
-	{ PrintError => 0 }            # Additional options
+	{ PrintError => 1 }            # Additional options
     );
 
-    # SIMPLE QUERIES
+    #### SIMPLE QUERIES
 
     $db->query('DELETE FROM foo');
-
     die "$db->{reason} ($DBI::errstr)" if not $db->{success};
-    # Error checking is omitted in the rest of this synopsis.
 
     for (1..100) {
 	$db->query(
@@ -148,12 +191,14 @@ DBIx::Simple - An easy-to-use, object oriented interface to DBI
 	);
     }
 
-    # SINGLE ROW QUERIES
+    #### SINGLE ROW QUERIES
 
     my ($two)          = $db->query('SELECT 1 + 1')->list;
     my ($three, $four) = $db->query('SELECT 3, 2 + 2')->list;
 
-    # FETCHING ALL IN ONE GO (not for large results!)
+    #### FETCHING ALL IN ONE GO
+
+    my @names = $db->query('SELECT name FROM people WHERE foo > 5')->flat;
 
     for my $row ($db->query('SELECT field1, field2 FROM foo')->arrays) {
 	print "--> $row->[0], $row->[1]\n";
@@ -162,9 +207,9 @@ DBIx::Simple - An easy-to-use, object oriented interface to DBI
     for my $row ($db->query('SELECT field1, field2 FROM foo')->hashes) {
 	print "--> $row->{field1}, $row->{field2}\n";
     }
-    
-    # FETCHING ONE ROW AT A TIME
-    
+
+    #### FETCHING ONE ROW AT A TIME
+
     {
 	my $result = $db->query('SELECT field1, field2 FROM foo');
 	while (my $row = $result->array) {
@@ -179,6 +224,26 @@ DBIx::Simple - An easy-to-use, object oriented interface to DBI
 	}
     }
 
+    #### BUILDING MAPS (also fetching all in one go)
+
+    # Hash of hashes
+    my $customers =
+	$db
+	-> query('SELECT id, name, location FROM people')
+	-> map_hashes('id');
+
+    # Hash of arrays
+    my $customers =
+	$db
+	-> query('SELECT id, name, location FROM people')
+	-> map_arrays(0);
+
+    # Hash of values
+    my $names =
+	$db
+	-> query('SELECT id, name FROM people')
+	-> map;
+
 =head1 DESCRIPTION
 
 This module is aimed at ease of use, not at SQL abstraction or
@@ -211,6 +276,10 @@ along to replace placeholders.  query() returns a new
 DBIx::Simple::Result object (or DBIx::Simple::Dummy), that can be
 used immediately to get data out of it.
 
+=item C<commit>, C<rollback>
+
+These just call the DBI methods and Do What You Mean.
+
 =item C<disconnect>
 
 Does What You Mean. Also note that the connection is automatically
@@ -243,12 +312,31 @@ These methods return a single row, in an array reference, or a hash
 reference, respectively.  Internally, fetchrow_arrayref or
 fetchrow_hashref is used.
 
+=item C<flat>
+
+flat() Returns a list of all returned fields, flattened. This can be
+very useful if you select a single column. Consider flat to be 
+list()'s plural.
+
 =item C<arrays> and C<hashes>
 
 These methods return a list of rows of array or hash references.
 Internally, fetchall_arrayref is dereferenced, or a lot of
 fetchrow_hashref returns are accumulated.
 
+=item C<map_arrays(column number)> and C<map_hashes(column name)>
+
+These methods build a hash, with the chosen column as keys, and the
+remaining columns in array or hash references as values. For
+C<map_arrays>, the column number is optional and defaults to 0 (the
+first column). The methods return a reference to the built hash.
+
+=item C<map>
+
+Returns a reference to a hash that was built using the first two 
+columns as key/value pairs. Use this only if your query returns two
+values per row (other values will be discarded).
+
 =item C<rows>
 
 Returns the number of rows.
@@ -256,8 +344,8 @@ Returns the number of rows.
 =item finish?
 
 There is no finish method. To finish the statement, just let the
-object go out of scope (you should always use "C<my>", and "C<use
-strict>") or destroy it explicitly using C<undef $result>.
+object go out of scope (you should always use "C<my>", and
+"C<use strict>") or destroy it explicitly using C<undef $result>.
 
 =back
 
@@ -278,6 +366,9 @@ course, this module shares all DBI bugs. If you want to report a
 bug, please try to find out if it's DBIx::Simple's fault or DBI's
 fault first, and don't report DBI bugs to me.
 
+Note: the map functions do not check if the key values are unique. If
+they are not, keys are overwritten.
+
 =head1 USE THIS MODULE AT YOUR OWN RISK
 
 No warranty, no guarantees. I hereby disclaim all responsibility for
